BasiCO Documentation
==================================

BasiCO is a simplified interface to using COPASI from python.
It is a collection of utility python scripts, that hide the 
complexity of the underlying SWIG generated language bindings. 

.. image:: ./_static/COPASI_Conly_176x176.png
   :alt: COPASI logo

.. toctree::
   :maxdepth: 2
   :caption: Getting started

   quickstart/get-started

.. toctree::
   :maxdepth: 2
   :caption: Examples

   notebooks/Accessing_Models_from_Databases
   notebooks/Creating_a_simple_model
   notebooks/Model_manipulation
   notebooks/Editing_Kinetics
   notebooks/Parameter_Estimation_Example
   notebooks/Setting_up_Parameter_Estimation
   notebooks/ParameterEstimation_Export
   notebooks/Optimization
   notebooks/Simple_simulations_and_plotting_with_basico
   notebooks/Simple_simulations_with_basico
   notebooks/CustomTimecourse
   notebooks/Parameter_Scans
   notebooks/Sensitivity_Analysis
   notebooks/Arrays_of_Compartments
   notebooks/Using_callbacks
   notebooks/Working_with_Plots
   notebooks/Working_with_Reports
   notebooks/Working_with_SBML_Ids
   notebooks/Working_with_Annotations
   notebooks/Working_with_ipyparallel
   notebooks/Working_with_PEtab
   notebooks/Working_with_ParameterSets
   notebooks/Profile_likelihood
   notebooks/MCA

.. toctree::
   :maxdepth: 2
   :caption: API

   API/modules

.. toctree::
   :maxdepth: 2
   :caption: Reference documentation
